@@ -38,10 +38,8 @@ let scm_best_path args =
     let pos = ScmTypes.exact_int_of_datum (ScmTypes.caddr args) in
     let len = ScmTypes.exact_int_of_datum (ScmTypes.cadddr args) in
     let parse_obj = Parse.parse string ~state ~pos ~len in
-    let path, state, cost = Parse.best_path parse_obj (pos + len) in
-    scm_list [scm_path path; 
-	      ScmTypes.datum_of_int state;
-	      ScmTypes.datum_of_int cost]
+    let path = Parse.best_path parse_obj (pos + len) in
+    scm_path path
   with Not_found -> ScmTypes.Nil
 
 let rec scm_candidates = function
