@@ -122,6 +122,7 @@ let list_next_mrph string ~pos ~len =
   Chasen.darts_lookup_prefix string pos len
 
 let parse string ~state ~pos ~len =
+  if len <= 0 then Array.init 0 Hashtbl.create else
   let init_node = 
     {pos = pos; state = state; path_cost = 0; 
      out_vertex_list = [];
@@ -144,6 +145,7 @@ let parse string ~state ~pos ~len =
   node_set
 
 let best_path node_set pos =
+  if Array.length node_set = 0 then [] else
   (*Ǹΰ֤ˤΡɤǺŬΤ*)
   let last_node =	
     let last_slice = node_set.(pos) in
@@ -168,8 +170,7 @@ let best_path node_set pos =
 	  gather n' path'
     | _ -> assert false)
     with Not_found -> path in
-  let path =  gather last_node [] in
-  (path, last_node.state, last_node.path_cost)
+  gather last_node []
   
 let list_candidates string ~state ~pos ~mrph_len ~len =
   let mrph_list = Chasen.darts_lookup string pos mrph_len in
